/**
 * 
 */
package com.primeton.mdm.demo.core.biz;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;

import com.eos.spring.BeanFactory;
import com.eos.system.annotation.Bizlet;
import com.eos.system.utility.PageResultList;
import com.primeton.gocom.afcenter.common.model.QueryConditionModel;
import com.primeton.gocom.afcenter.common.model.QueryConditionModel.QueryConditionItem;
import com.primeton.mdm.commons.model.MDMPageRequest;
import com.primeton.mdm.demo.core.service.DataOpsService;
import com.primeton.mdm.demo.core.util.DataObjectUtils;
import com.primeton.mdm.management.vo.MDMQueryParam;
import com.primeton.spring.DefaultBeanFactory;

import commonj.sdo.DataObject;

/**
 * @author tianxinhui
 * @date 2023-04-04 16:27:08
 *
 */
@Service
@Bizlet("EnterpriseInfoBiz")
public class EnterpriseInfoBiz {
	private static final String DATA_MODEL_CODE = "enterprise";

	private BeanFactory factory = new DefaultBeanFactory();

	private DataOpsService service = (DataOpsService) factory.getBean("dataOpsService");

	@Bizlet("addEnterpriseInfo")
	public void addEnterpriseInfo(DataObject data) {
		service.insertData(DATA_MODEL_CODE, DataObjectUtils.toEnterpriseInfo(data));
	}

	@Bizlet("batchInsertEnterpriseInfo")
	public void batchInsertEnterpriseInfo(DataObject[] data) {
		if (data == null || data.length == 0) {
			return;
		}
		List<Map<String, Object>> dataList = new ArrayList<>();
		for (DataObject item : data) {
			dataList.add(DataObjectUtils.toEnterpriseInfo(item));
		}
		service.batchInsertData(DATA_MODEL_CODE, dataList);
	}

	@Bizlet("releaseEnterpriseInfo")
	public void releaseEnterpriseInfo(String dataId) {
		service.releaseData(DATA_MODEL_CODE, dataId);
	}

	@Bizlet("findEnterpriseInfoById")
	public Object findEnterpriseInfoById(String dataId) {
		return service.findDataById(DATA_MODEL_CODE, dataId);
	}

	@Bizlet("findEnterpriseInfo")
	public PageResultList<Object> findEnterpriseInfo(QueryConditionModel query, int pageIndex, int pageSize) {
		QueryConditionItem[] andItems = query.getAnd().getItems();
		MDMQueryParam params = new MDMQueryParam();
		for (QueryConditionItem item : andItems) {
			MDMQueryParam.Arg arg = new MDMQueryParam.Arg();
			arg.setName(item.getPropertyName());
			arg.setMatchValue(String.valueOf(item.getPropertyValue()));
			params.setArgs(Arrays.asList(arg));
		}

		MDMPageRequest page = new MDMPageRequest();
		page.setPageIndex(pageIndex);
		page.setPageSize(pageSize);
		Page<Map<String, Object>> result = service.findData(DATA_MODEL_CODE, params, page);

		List<Map<String, Object>> content = result.getContent();

		PageResultList pageResult = new PageResultList<>();
		pageResult.setData(content);
		pageResult.setTotal((int) result.getTotalElements());
		return pageResult;
	}

	@Bizlet("updateEnterpriseInfo")
	public void updateEnterpriseInfo(DataObject data) {
		service.updateData(DATA_MODEL_CODE, DataObjectUtils.toEnterpriseInfo(data));
	}

	@Bizlet("batchUpdateEnterpriseInfo")
	public void batchUpdateEnterpriseInfo(DataObject[] data) {
		if (data == null || data.length == 0) {
			return;
		}
		List<Map<String, Object>> dataList = new ArrayList<>();
		for (DataObject item : data) {
			dataList.add(DataObjectUtils.toEnterpriseInfo(item));
		}
		service.batchUpdataData(DATA_MODEL_CODE, dataList);
	}

	@Bizlet("deleteEnterpriseInfo")
	public void deleteEnterpriseInfo(String dataId) {
		service.deleteData(DATA_MODEL_CODE, dataId);
	}

	@Bizlet("batchDeleteEnterpriseInfo")
	public Object[] batchDeleteEnterpriseInfo(String[] dataIds) {
		if (dataIds == null || dataIds.length == 0) {
			return new Object[0];
		}
		// 用于返回结果，也可以不返回
		Object[] result = new Object[dataIds.length];
		try {
			service.batchDeleteData(DATA_MODEL_CODE, Arrays.asList(dataIds));
			for (int i = 0; i < result.length; i++) {
				Map<String, Object> data = new HashMap<>();
				data.put("M_ID", dataIds[i]);
				result[i] = data;
			}
		} catch (Exception e) {
			e.printStackTrace();
		}
		return result;
	}
}
