package com.primeton.mdm.demo.core.service;

import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.data.domain.Page;
import org.springframework.stereotype.Service;

import com.primeton.mdm.commons.model.MDMPageRequest;
import com.primeton.mdm.management.service.MDMBizTableService;
import com.primeton.mdm.management.spi.MDMDataModelTableHandler;
import com.primeton.mdm.management.util.MDMDataModelTableHelper;
import com.primeton.mdm.management.vo.MDMQueryParam;

/**
 * @author tianxinhui
 */
@Service
@Qualifier("dataOpsService")
public class DataOpsService {
	@Autowired
	private MDMBizTableService service;

	@Autowired
	private MDMDataModelTableHelper helper;

	public void insertData(String dataModelCode, Map<String, Object> data) {
		if (StringUtils.isBlank(dataModelCode)) {
			throw new IllegalArgumentException("dataModelCode is null!");
		}
		helper.insert(dataModelCode, data);
	}

	public void insertDataAndRelease(String dataModelCode, Map<String, Object> data) {
		if (StringUtils.isBlank(dataModelCode)) {
			throw new IllegalArgumentException("dataModelCode is null!");
		}
		helper.insert(dataModelCode, data);
	}

	public void batchInsertData(String dataModelCode, List<Map<String, Object>> data) {
		if (StringUtils.isBlank(dataModelCode)) {
			throw new IllegalArgumentException("dataModelCode is null!");
		}
		helper.insert(dataModelCode, data);
	}

	public void releaseData(String dataModelCode, String dataId) {
		helper.release(dataModelCode, dataId);
	}

	public void updateData(String dataModelCode, Map<String, Object> data) {
		if (StringUtils.isBlank(dataModelCode)) {
			throw new IllegalArgumentException("dataModelCode is null!");
		}
		if (StringUtils.isBlank(String.valueOf(data.get(MDMDataModelTableHandler.RESERVED_FIELD_ID)))) {
			throw new IllegalArgumentException("dataId is null!");
		}
		helper.update(dataModelCode, String.valueOf(data.get(MDMDataModelTableHandler.RESERVED_FIELD_ID)), data, false);
	}

	public void batchUpdataData(String dataModelCode, List<Map<String, Object>> data) {
		helper.update(dataModelCode, data, false);
	}

	public void updateDataAndRelease(String dataModelCode, String dataId, Map<String, Object> data) {
		if (StringUtils.isBlank(dataModelCode)) {
			throw new IllegalArgumentException("dataModelCode is null!");
		}
		if (StringUtils.isBlank(dataId)) {
			throw new IllegalArgumentException("dataId is null!");
		}
		helper.updateAndRelease(dataModelCode, dataId, data, false);
	}

	public void deleteData(String dataModelCode, String dataId) {
		if (StringUtils.isBlank(dataModelCode)) {
			throw new IllegalArgumentException("dataModelCode is null!");
		}
		if (StringUtils.isBlank(dataId)) {
			throw new IllegalArgumentException("dataId is null!");
		}
		helper.delete(dataModelCode, dataId);
	}

	public void batchDeleteData(String dataModelCode, List<String> dataIds) {
		if (StringUtils.isBlank(dataModelCode)) {
			throw new IllegalArgumentException("dataModelCode is null!");
		}
		if (dataIds == null || dataIds.size() == 0) {
			throw new IllegalArgumentException("dataIds is null!");
		}
		helper.delete(dataModelCode, dataIds);
	}

	public Map<String, Object> findDataById(String dataModelCode, String dataId) {
		if (StringUtils.isBlank(dataModelCode)) {
			throw new IllegalArgumentException("dataModelCode is null!");
		}
		if (StringUtils.isBlank(dataId)) {
			throw new IllegalArgumentException("dataId is null!");
		}
		MDMQueryParam.Arg arg = new MDMQueryParam.Arg();
		arg.setName(MDMDataModelTableHandler.RESERVED_FIELD_ID);
		arg.setMatchValue(dataId);
		MDMQueryParam.ParseRef parseRef = new MDMQueryParam.ParseRef();
		parseRef.setParseRefReferenceField(true);
		MDMQueryParam param = new MDMQueryParam();
		param.setArgs(Collections.singletonList(arg));
		param.setParseRef(parseRef);
		;
		Page<Map<String, Object>> result = service.findData(dataModelCode, true, param, null, new HashMap<>());
		List<Map<String, Object>> content = result.getContent();
		return content.size() != 0 ? content.get(0) : new HashMap<>();
	}

	public Page<Map<String, Object>> findData(String dataModelCode, MDMQueryParam params, MDMPageRequest page) {
		if (StringUtils.isBlank(dataModelCode)) {
			throw new IllegalArgumentException("dataModelCode is null!");
		}
		if (page == null) {
			page = new MDMPageRequest(0, 10);
		}
		if (params == null) {
			params = new MDMQueryParam();
			params.getParseRef().setParseRefReferenceField(true);
		}
		return service.findData(dataModelCode, true, params, page, new HashMap<>());
	}
}
